@@ -18,14 +18,7 @@
 # Boston, MA 02111-1307, USA.
 #
 
-from __future__ import with_statement
-from __future__ import absolute_import
-from __future__ import division
-from __future__ import print_function
-from __future__ import unicode_literals
-
 import os
-import subprocess
 import tempfile
 
 from .libtoolimporter import LibtoolImporter
@@ -275,6 +268,9 @@ class SourceScanner(object):
     def get_comments(self):
         return self._scanner.get_comments()
 
+    def get_errors(self):
+        return self._scanner.get_errors()
+
     def dump(self):
         print('-' * 30)
         for symbol in self._scanner.get_symbols():
@@ -308,10 +304,7 @@ class SourceScanner(object):
                       self._cpp_options)
 
         os.unlink(tmp_name_cpp)
-        fp = open(tmpfile_output, 'r')
-
-        self._scanner.parse_file(fp.fileno())
-        fp.close()
+        self._scanner.parse_file(tmpfile_output)
         os.unlink(tmpfile_output)
 
     def _write_preprocess_src(self, fp, defines, undefs, filenames):
