@@ -4,6 +4,7 @@
 #ifndef _GI_DISABLE_CAIRO
 #include <cairo-gobject.h>
 #endif
+#include <glib.h>
 #include <glib-object.h>
 #include <gio/gio.h>
 #include <time.h>
@@ -780,6 +781,7 @@ struct _RegressTestObj
   char* string;
   GType gtype;
   gint name_conflict;
+  GByteArray *byte_array;
 
   /* < private > */
   void (*function_ptr) (void);
@@ -967,6 +969,9 @@ typedef struct _RegressTestSubObjClass    RegressTestSubObjClass;
 struct _RegressTestSubObj
 {
   RegressTestObj parent_instance;
+  /*< private >*/
+  gint number;
+  gboolean boolean;
 };
 
 struct _RegressTestSubObjClass
@@ -1490,4 +1495,11 @@ typedef struct {
 GVariant *
 regress_get_variant (void);
 
+typedef struct _RegressTestReferenceCounters RegressTestReferenceCounters;
+
+struct _RegressTestReferenceCounters {
+  grefcount       refcount;
+  gatomicrefcount atomicrefcount;
+};
+
 #endif /* __GITESTTYPES_H__ */
